@@ -1,19 +1,19 @@
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-import collections
-import hashlib
+from collections import Hashable
+from functools import partial
 import logging
+from os.path import dirname
 import re
 import sys
 import threading
-from functools import partial
 
+from .common.compat import on_win
 from .common.url import path_to_url
+from .gateways.disk.read import compute_md5sum
 
 log = logging.getLogger(__name__)
 
-on_win = bool(sys.platform == "win32")
-
 
 class memoized(object):
     """Decorator. Caches a function's return value each time it is called.
@@ -30,7 +30,7 @@ class memoized(object):
         for arg in args:
             if isinstance(arg, list):
                 newargs.append(tuple(arg))
-            elif not isinstance(arg, collections.Hashable):
+            elif not isinstance(arg, Hashable):
                 # uncacheable. a list, for instance.
                 # better to not cache than blow up.
                 return self.func(*args, **kw)
@@ -70,38 +70,6 @@ class memoize(object):  # 577452
             res = cache[key] = self.func(*args, **kw)
         return res
 
-@memoized
-def gnu_get_libc_version():
-    """
-    If on linux, get installed version of glibc, otherwise return None
-    """
-
-    if not sys.platform.startswith('linux'):
-        return None
-
-    from ctypes import CDLL, cdll, c_char_p
-
-    cdll.LoadLibrary('libc.so.6')
-    libc = CDLL('libc.so.6')
-    f = libc.gnu_get_libc_version
-    f.restype = c_char_p
-    return f()
-
-
-def hashsum_file(path, mode='md5'):
-    h = hashlib.new(mode)
-    with open(path, 'rb') as fi:
-        while True:
-            chunk = fi.read(262144)  # process chunks of 256KB
-            if not chunk:
-                break
-            h.update(chunk)
-    return h.hexdigest()
-
-
-def md5_file(path):
-    return hashsum_file(path, 'md5')
-
 
 def path_identity(path):
     """Used as a dummy path converter where no conversion necessary"""
@@ -294,3 +262,39 @@ else:
 
 # put back because of conda build
 urlpath = url_path = path_to_url
+md5_file = compute_md5sum
+
+import hashlib  # NOQA
+
+
+def hashsum_file(path, mode='md5'):
+    h = hashlib.new(mode)
+    with open(path, 'rb') as fi:
+        while True:
+            chunk = fi.read(262144)  # process chunks of 256KB
+            if not chunk:
+                break
+            h.update(chunk)
+    return h.hexdigest()
+
+
+@memoized
+def sys_prefix_unfollowed():
+    """Since conda is installed into non-root environments as a symlink only
+    and because sys.prefix follows symlinks, this function can be used to
+    get the 'unfollowed' sys.prefix.
+
+    This value is usually the same as the prefix of the environment into
+    which conda has been symlinked. An example of when this is necessary
+    is when conda looks for external sub-commands in find_commands.py
+    """
+    try:
+        frame = next(iter(sys._current_frames().values()))
+        while frame.f_back:
+            frame = frame.f_back
+        code = frame.f_code
+        filename = code.co_filename
+        unfollowed = dirname(dirname(filename))
+    except:
+        return sys.prefix
+    return unfollowed
